@@ -3,7 +3,6 @@
 from __future__ import annotations
 
 import calendar
-import inspect
 import json
 import os
 import pathlib
@@ -11,16 +10,16 @@ import threading
 import time
 from collections import deque
 from dataclasses import dataclass, field, asdict
-from functools import wraps
 from tqdm import tqdm
-from typing import List, Callable, Dict
+from typing import List, Dict
 
 import matplotlib.pyplot as plt
 import numpy as np
 from serial import Serial
 
 BUFFER = 480
-MAX_FREQ = 4000
+MAX_FREQ = 32000
+REAL_MAX_FREQ = 20000
 MAX_PULSE_WIDTH = 32767
 BAUDRATE = 115200
 
@@ -51,7 +50,7 @@ class ArduscopeMeasure:
 
     x: np.ndarray = field(init=False)
     channels: List[np.ndarray] = list
-    version: str = "0.1.2"
+    version: str = "0.2.1"
 
     def __post_init__(self):
         self.acquire_time = float(self.acquire_time)
@@ -442,6 +441,12 @@ class Arduscope:
                 raise ValueError(f"Trigger value {self._trigger_value}V "
                                  f"greater than maximum amplitude {self._ref}V.")
 
+        if self._freq > REAL_MAX_FREQ / self._n_channels:
+            print(f"\n*** WARNING ***"
+                  f"\nMAXIMUM RECOMMENDED FREQUENCY FOR {self._n_channels} CHANNELS "
+                  f"IS {int(REAL_MAX_FREQ / self._n_channels):d}Hz.\n"
+                  f"***\n")
+
         self._measure_params = {
             "acquire_time": time.time(),
             "frequency": self.frequency,
@@ -519,6 +524,7 @@ class Arduscope:
                     pb.update(current_screens - pb.n)
                     current_screens = len(self._data_buffer)
                 pb.update(n_screens - pb.n)
+            print()
 
     def stop_acquire(self):
         """ Stops acquire without clearing the buffer """
@@ -529,6 +535,8 @@ class Arduscope:
                 self._running.clear()
                 self._daemon.join()
 
+        Arduscope._open_ports.pop(self._port, None)
+
     def close(self):
         self.stop_acquire()
         self._serial.close()
@@ -585,7 +593,7 @@ class Arduscope:
         ax.set_ylabel("Voltage (V)", fontsize=14)
         ax.legend(loc=1, fontsize=14)
 
-    def live_plot(self):
+    def live_plot(self, close_after: int = None):
         """ Deploy a Matplotlib window with the live state of Arduscope """
         if not self._running.isSet():
             raise RuntimeError('First call "start_acquire()"')
@@ -630,17 +638,23 @@ class Arduscope:
             total=self._data_buffer.maxlen,
             initial=current_screens,
             ncols=80,
-            bar_format = "{desc}: {percentage:3.0f}%|{bar}| {n_fmt}/{total_fmt}"
+            bar_format="{desc}: {percentage:3.0f}%|{bar}| {n_fmt}/{total_fmt}"
         ) as pb:
             pb.set_description("Live mode on. Screen buffer status")
             while self._live_mode_on is True:
-                plt.pause(0.001)
+                if close_after is not None:
+                    if len(self._data_buffer) >= close_after:
+                        plt.close(fig)
+                        self._live_mode_on = False
+                fig.canvas.draw_idle()
+                fig.canvas.flush_events()
                 if self._screen_ready.isSet():
                     for i, channel in enumerate(self._data_buffer[-1]):
                         curves[i].set_data(self.x, channel)
                     self._screen_ready.clear()
                 pb.update(current_screens - pb.n)
                 current_screens = len(self._data_buffer)
-
         if interactive_state is False:
             plt.ioff()
+
+        print("\n")
